AsyncError<T> class

State for an AsyncState with an error

Inheritance

Constructors

AsyncError(Object error, StackTrace stackTrace)
State for an AsyncState with an error
const

Properties

error → Object
Returns the error of the state.
final
hasError → bool
Returns true if the state has an error
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
hasValue → bool
Returns true if the state has a value
no setteroverride
isLoading → bool
Check if the state is a loading state
no setteroverride
isRefreshing → bool
Returns true if the state is refreshing with a loading flag, has a value or error and is not the loading state
no setteroverride
isReloading → bool
Returns true if the state is reloading with having a value or error, and is the loading state
no setteroverride
requireValue → T
Force unwrap the value of the state.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace
Returns the stack trace of the state.
final
value → T?
Returns the value of the state.
no setteroverride

Methods

map<E>({required AsyncDataBuilder<E, T> data, required AsyncErrorBuilder<E> error, required AsyncStateBuilder<E> loading, AsyncStateBuilder<E>? reloading, AsyncStateBuilder<E>? refreshing}) → E
Map the state to a value.
inherited
maybeMap<E>({AsyncDataBuilder<E, T>? data, AsyncErrorBuilder<E>? error, AsyncStateBuilder<E>? loading, AsyncStateBuilder<E>? reloading, AsyncStateBuilder<E>? refreshing, required AsyncStateBuilder<E> orElse}) → E
Map the state to a value with optional or else.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(covariant AsyncState other) → bool
The equality operator.
override