ReadonlySignalOptions<T> class

Configuration options for a ReadonlySignal extending signals.ReadonlySignalOptions.

Constructors

ReadonlySignalOptions({String? name, bool autoDispose = false, void watched()?, void unwatched()?})
Creates a new ReadonlySignalOptions instance.
const

Properties

autoDispose bool
Automatically dispose the signal when there are no more listeners.
final
hashCode int
The hash code for this object.
no setter
name String?
The name for debugging, tracing, and DevTools inspection.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toSignalOptions SignalOptions<T>
Convert to SignalOptions
no setter
unwatched → void Function()?
Callback called when the signal goes from >=1 to 0 listeners.
finalinherited
watched → void Function()?
Callback called when the signal goes from 0 to >=1 listeners.
finalinherited

Methods

copyWith({String? name, bool? autoDispose, void watched()?, void unwatched()?}) ReadonlySignalOptions<T>
Creates a copy of this options with custom overrides.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.