ReadonlySignalUtils<T> extension

Utility extensions on ReadonlySignal to bridge reactive programming with asynchronous streams and select sub-states.

on

Methods

select<R>(R selector(ReadonlySignal<T>), [ComputedOptions<R>? options]) Computed<R>

Available on ReadonlySignal<T>, provided by the ReadonlySignalUtils extension

Select a sub-state value from this signal and return a computed signal that only notifies when that specific sub-state changes.
toStream() Stream<T>

Available on ReadonlySignal<T>, provided by the ReadonlySignalUtils extension

Convert a signal to a Stream to be consumed as a read only stream.