SignalsInMemoryKeyValueStore class

An in-memory, volatile implementation of SignalsKeyValueStore.

This serves as a fallback engine and does not persist across restarts/reload.

@link https://dartsignals.dev/utilities/persisted

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store Map<String, String?>
The in-memory store.
final

Methods

getItem(String key) Future<String?>
Gets an item from the store.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeItem(String key) Future<void>
Removes an item from the store.
override
setItem(String key, String value) Future<void>
Sets an item in the store.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited