ListSignalOptions<E> class
Configuration options for a ListSignal.
- Inheritance
-
- Object
- SignalOptions<
List< E> > - ListSignalOptions
Constructors
-
ListSignalOptions({String? name, bool autoDispose = false, void watched()?, void unwatched()?, SignalEquality<
List< ? equality = const SignalDeepEquality()})E> > -
Creates a new ListSignalOptions instance.
const
Properties
- autoDispose → bool
-
Automatically dispose the signal when there are no more listeners.
finalinherited
-
equalityCheck
→ SignalEquality<
List< E> > -
Get the active equality check
no setterinherited
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String?
-
The name for debugging, tracing, and DevTools inspection.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unwatched → void Function()?
-
Callback called when the signal goes from >=1 to 0 listeners.
finalinherited
- watched → void Function()?
-
Callback called when the signal goes from 0 to >=1 listeners.
finalinherited
Methods
-
copyWith(
{String? name, bool? autoDispose, void watched()?, void unwatched()?, SignalEquality< List< ? equality}) → ListSignalOptions<E> >E> -
Creates a copy of this options with custom overrides.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override